Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2670)

Unified Diff: chrome/browser/media/cast_transport_host_filter.h

Issue 2075153002: Reland of 'Move content/browser/power_save_blocker to //device/power_save_blocker' (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: missing libs for component mac Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/media/DEPS ('k') | chrome/browser/media/cast_transport_host_filter.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/media/cast_transport_host_filter.h
diff --git a/chrome/browser/media/cast_transport_host_filter.h b/chrome/browser/media/cast_transport_host_filter.h
index ad9818e027663bea507693fbfb2212e4d5c7e452..fefde8b144946c47571881e0a685619138178ca6 100644
--- a/chrome/browser/media/cast_transport_host_filter.h
+++ b/chrome/browser/media/cast_transport_host_filter.h
@@ -19,9 +19,9 @@
#include "media/cast/net/cast_transport.h"
#include "media/cast/net/udp_transport.h"
-namespace content {
+namespace device {
class PowerSaveBlocker;
-} // namespace content
+} // namespace device
namespace cast {
@@ -91,9 +91,9 @@ class CastTransportHostFilter : public content::BrowserMessageFilter {
base::DefaultTickClock clock_;
// While |id_map_| is non-empty, hold an instance of
// content::PowerSaveBlocker. This prevents Chrome from being suspended while
// remoting content.
- std::unique_ptr<content::PowerSaveBlocker> power_save_blocker_;
+ std::unique_ptr<device::PowerSaveBlocker> power_save_blocker_;
base::WeakPtrFactory<CastTransportHostFilter> weak_factory_;
« no previous file with comments | « chrome/browser/media/DEPS ('k') | chrome/browser/media/cast_transport_host_filter.cc » ('j') | no next file with comments »
@@ -91,9 +91,9 @@ class CastTransportHostFilter : public content::BrowserMessageFilter {
base::DefaultTickClock clock_;
// While |id_map_| is non-empty, hold an instance of
- // content::PowerSaveBlocker. This prevents Chrome from being suspended while
+ // device::PowerSaveBlocker. This prevents Chrome from being suspended while
// remoting content.

Powered by Google App Engine
This is Rietveld 408576698